Learn R Programming

stm (version 1.0.8)

gadarian: Gadarian and Albertson data

Description

This data set contains variables from Gadarian and Albertson, forthcoming, "Anxiety, Immigration, and the Search for Information", Political Psychology. The experiment had those in the treatment condition write about what made them anxious about immigration. The control condition just had subjects write about immigration.

Usage

data(gadarian)

Arguments

source

Gadarian and Albertson, forthcoming, "Anxiety, Immigration, and the Search for Information", Political Psychology http://onlinelibrary.wiley.com/doi/10.1111/pops.12034/abstract Roberts, M., Stewart, B., Tingley, D., Lucas, C., Leder-Luis, J., Gadarian, S., Albertson, B., Albertson, B. and Rand, D. (Forthcoming). "Structural topic models for open ended survey responses." American Journal of Political Science http://goo.gl/0x0tHJ

Examples

Run this code
head(gadarian)
#Process the data for analysis.
temp<-textProcessor(documents=gadarian$open.ended.response,metadata=gadarian)
meta<-temp$meta
vocab<-temp$vocab
docs<-temp$documents
out <- prepDocuments(docs, vocab, meta)
docs<-out$documents
vocab<-out$vocab
meta <-out$meta

Run the code above in your browser using DataLab